<?php
/*
* 2007-2017 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2015 PrestaShop SA
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

// on recupere le fichier de connection à la base de données
require_once dirname(__FILE__).'/conf.php';

class Payplus extends PaymentModule
{
    public function __construct()
    {
        $this->name = 'payplus';
        $this->tab = 'payments_gateways';
        $this->version = '0.1';
        $this->author = 'La Pieuvre Technologique';
        $this->bootstrap = true;
        
        parent::__construct();
        
        switch (_PAYMENT_PLATFORM) {
            case "payplus":
                $this->displayName = $this->l('PayPlus');
                break;
            case "ligdicash":
                $this->displayName = $this->l('Ligdi Cash');
                break;
            default:
                $this->displayName = $this->l('PayPlus');
                break;
        }

        $this->description = $this->l('Acceptez des paiements mobile de manière simple, rapide et sécurisée.');
        
    }

    public function install()
    {
        if (!parent::install() 
            or !$this->registerHook('displayPayment') 
            or !$this->registerHook('displayPaymentReturn')
            or !Configuration::updateValue('PayPlus_PAYNOW_TEXT', 'Paiement mobile')
            or !Configuration::updateValue('PayPlus_PAYNOW_DESCRIPTION', 'Effectuez des paiements mobile de manière simple, rapide et sécurisée')
            or !Configuration::updateValue('PayPlus_API_KEY', '')
            or !Configuration::updateValue('PayPlus_PRIVATEAPI_KEY', '')
            or !Configuration::updateValue('PayPlus_TOKEN', '')
            or !Configuration::updateValue('PayPlus_MODE', 'test')
            or !Configuration::updateValue('PayPlus_SUCCESS_MESSAGE', 'Félicitations, votre commande a été effectuée avec succès.')
            or !Configuration::updateValue('PayPlus_ERROR_MESSAGE', 'La transaction a échoué.')){
            return false;
        }

        if (!$this->installOrderState()) {
            return false;
        }
        
        return true;
    }

    // Retrocompatibility 1.4/1.5

    public function uninstall()
    {
        unlink(dirname(__FILE__) . '/../../cache/class_index.php');
        return (parent::uninstall()
            and Configuration::deleteByName('PayPlus_PAYNOW_TEXT')
            and Configuration::deleteByName('PayPlus_PAYNOW_DESCRIPTION')
            and Configuration::deleteByName('PayPlus_API_KEY')
            and Configuration::deleteByName('PayPlus_PRIVATEAPI_KEY')
            and Configuration::deleteByName('PayPlus_TOKEN')
            and Configuration::deleteByName('PayPlus_MODE')
            and Configuration::deleteByName('PayPlus_SUCCESS_MESSAGE')
            and Configuration::deleteByName('PayPlus_ERROR_MESSAGE')
        );
    }

    public function installOrderState()
    {
        if (Configuration::get('PS_OS_PayPlus_PAYMENT') < 1)
        {
            $order_state = new OrderState();
            $order_state->send_email = false;
            $order_state->module_name = $this->name;
            $order_state->invoice = false;
            $order_state->color = '#98c3ff';
            $order_state->logable = true;
            $order_state->shipped = false;
            $order_state->unremovable = false;
            $order_state->delivery = false;
            $order_state->hidden = false;
            $order_state->paid = false;
            $order_state->deleted = false;
            $order_state->name = array((int)Configuration::get('PS_LANG_DEFAULT') => pSQL($this->l('PayPlus - En attente de paiement')));

            if ($order_state->add())
            {
                // We save the order State ID in Configuration database
                Configuration::updateValue('PS_OS_PayPlus_PAYMENT', $order_state->id);

                // We copy the module logo in order state logo directory
                copy(dirname(__FILE__).'/'._PAYMENT_PLATFORM.'.png', dirname(__FILE__).'/../../img/os/'.$order_state->id.'.png');
                copy(dirname(__FILE__).'/'._PAYMENT_PLATFORM.'.png', dirname(__FILE__).'/../../img/tmp/order_state_mini_'.$order_state->id.'.png');
            }
            else {
                return false;
            }
        }
        return true;
    }

    public function hookDisplayPayment($params)
    {   
        $controller = $this->getHookController('displayPayment');
        return $controller->run($params);
    }

    public function hookDisplayPaymentReturn($params)
    {
        $controller = $this->getHookController('displayPaymentReturn');
        return $controller->run($params);
    }

    public function getContent()
    {
        $controller = $this->getHookController('getContent');
        return $controller->run();
    }

    public function getHookController($hook_name)
    {
        // Include the controller file
        require_once(dirname(__FILE__).'/controllers/hook/'. $hook_name.'.php');

        // Build dynamically the controller name
        $controller_name = $this->name.$hook_name.'Controller';

        // Instantiate controller
        $controller = new $controller_name($this, __FILE__, $this->_path);

        // Return the controller
        return $controller;
    }
}